==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/RemoveContentFooterAction.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.EdmSchemaInfo;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "uiElementNames"})
@JsonInclude(Include.NON_NULL)
public class RemoveContentFooterAction extends InformationProtectionAction implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("uiElementNames")
    protected List<String> uiElementNames;

    @JsonProperty("uiElementNames@nextLink")
    protected String uiElementNamesNextLink;

    protected RemoveContentFooterAction() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.removeContentFooterAction";
    }

    @Property(name="uiElementNames")
    @JsonIgnore
    public CollectionPage<String> getUiElementNames() {
        return new CollectionPage<String>(contextPath, String.class, uiElementNames, Optional.ofNullable(uiElementNamesNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="uiElementNames")
    @JsonIgnore
    public CollectionPage<String> getUiElementNames(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, uiElementNames, Optional.ofNullable(uiElementNamesNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderRemoveContentFooterAction() {
        return new Builder();
    }

    public static final class Builder {
        private List<String> uiElementNames;
        private String uiElementNamesNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder uiElementNames(List<String> uiElementNames) {
            this.uiElementNames = uiElementNames;
            this.changedFields = changedFields.add("uiElementNames");
            return this;
        }

        public Builder uiElementNames(String... uiElementNames) {
            return uiElementNames(Arrays.asList(uiElementNames));
        }

        public Builder uiElementNamesNextLink(String uiElementNamesNextLink) {
            this.uiElementNamesNextLink = uiElementNamesNextLink;
            this.changedFields = changedFields.add("uiElementNames");
            return this;
        }

        public RemoveContentFooterAction build() {
            RemoveContentFooterAction _x = new RemoveContentFooterAction();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.removeContentFooterAction";
            _x.uiElementNames = uiElementNames;
            _x.uiElementNamesNextLink = uiElementNamesNextLink;
            return _x;
        }
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RemoveContentFooterAction[");
        b.append("uiElementNames=");
        b.append(this.uiElementNames);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/RemoveContentFooterAction.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "uiElementNames"})
@JsonInclude(Include.NON_NULL)
public class RemoveContentFooterAction extends InformationProtectionAction implements ODataType {

    @JsonProperty("uiElementNames")
    protected List<String> uiElementNames;

    @JsonProperty("uiElementNames@nextLink")
    protected String uiElementNamesNextLink;

    protected RemoveContentFooterAction() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.removeContentFooterAction";
    }

    @Property(name="uiElementNames")
    @JsonIgnore
    public CollectionPage<String> getUiElementNames() {
        return new CollectionPage<String>(contextPath, String.class, this.uiElementNames, Optional.ofNullable(uiElementNamesNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="uiElementNames")
    @JsonIgnore
    public CollectionPage<String> getUiElementNames(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, this.uiElementNames, Optional.ofNullable(uiElementNamesNextLink), Collections.emptyList(), options);
    }

    public RemoveContentFooterAction withUnmappedField(String name, Object value) {
        RemoveContentFooterAction _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderRemoveContentFooterAction() {
        return new Builder();
    }

    public static final class Builder {
        private List<String> uiElementNames;
        private String uiElementNamesNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder uiElementNames(List<String> uiElementNames) {
            this.uiElementNames = uiElementNames;
            this.changedFields = changedFields.add("uiElementNames");
            return this;
        }

        public Builder uiElementNames(String... uiElementNames) {
            return uiElementNames(Arrays.asList(uiElementNames));
        }

        public Builder uiElementNamesNextLink(String uiElementNamesNextLink) {
            this.uiElementNamesNextLink = uiElementNamesNextLink;
            this.changedFields = changedFields.add("uiElementNames");
            return this;
        }

        public RemoveContentFooterAction build() {
            RemoveContentFooterAction _x = new RemoveContentFooterAction();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.removeContentFooterAction";
            _x.uiElementNames = uiElementNames;
            _x.uiElementNamesNextLink = uiElementNamesNextLink;
            return _x;
        }
    }

    private RemoveContentFooterAction _copy() {
        RemoveContentFooterAction _x = new RemoveContentFooterAction();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.uiElementNames = uiElementNames;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RemoveContentFooterAction[");
        b.append("uiElementNames=");
        b.append(this.uiElementNames);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
